==> vst3sdk-docs-3.7.7_build_19-1-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstgui/html/group__new__in__4__12.js <==
var group__new__in__4__12 =
[
    [ "CMultiFrameBitmapDescription", "struct_v_s_t_g_u_i_1_1_c_multi_frame_bitmap_description.html", [
      [ "frameSize", "struct_v_s_t_g_u_i_1_1_c_multi_frame_bitmap_description.html#a50a5b5db6f2de6a7a42bb1130fc39ae1", null ],
      [ "framesPerRow", "struct_v_s_t_g_u_i_1_1_c_multi_frame_bitmap_description.html#aa2418b196702389b4450205a22faffdd", null ],
      [ "numFrames", "struct_v_s_t_g_u_i_1_1_c_multi_frame_bitmap_description.html#aa1496e76b22f53183e34a50f248bd9ca", null ]
    ] ],
    [ "CMultiFrameBitmap", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html", [
      [ "CMultiFrameBitmap", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#aca5f87fd37c83997c7b40f736047ea8d", null ],
      [ "calcFrameRect", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#affba1bb7f8a5ce9bbc2a4df4ba9e4360", null ],
      [ "drawFrame", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#a95e9e603c2ae8d03090a645302f2e886", null ],
      [ "getFrameSize", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#a8eff0d7d0cf4e8754d52ded4ba7975bd", null ],
      [ "getMultiFrameDesc", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#a697a5151888674ab85ffc7c284ee685a", null ],
      [ "getNumFrames", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#a961e2602e761bbe633db870537066b66", null ],
      [ "getNumFramesPerRow", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#a12c2e7a55690f8792280a2255c3f4944", null ],
      [ "setMultiFrameDesc", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#a8eeea0f6b2541f6673a512e42ce52f57", null ]
    ] ],
    [ "DataPackageIterator", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html", [
      [ "Item", "struct_v_s_t_g_u_i_1_1_data_package_iterator_1_1_item.html", [
        [ "data", "struct_v_s_t_g_u_i_1_1_data_package_iterator_1_1_item.html#a0d49d74db4c035719c3867723cf7e779", null ],
        [ "dataSize", "struct_v_s_t_g_u_i_1_1_data_package_iterator_1_1_item.html#ae3c68f6750377179ad148e76693cc7d1", null ],
        [ "type", "struct_v_s_t_g_u_i_1_1_data_package_iterator_1_1_item.html#ae1794d09d5075e39c1df135ed5d8664b", null ]
      ] ],
      [ "DataPackageIterator", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html#a0078e479b4e2bbbf6aa57c7310b7c5e9", null ],
      [ "getIndex", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html#ac3e469963b1a1c531939acf71dc87d50", null ],
      [ "operator!=", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html#a7b2e488cbf486e45e7db5d9efc23fa07", null ],
      [ "operator*", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html#aa64bf704a52b7c7a3ec7f85ced201fc4", null ],
      [ "operator++", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html#a3a07e058aa38240bc9c57be8ef9c34fc", null ],
      [ "operator->", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html#a50569d3cd8bf25e88f91ae842ee49166", null ]
    ] ]
];

==> vst3sdk-docs-3.7.10_build_14-1-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstgui/html/group__new__in__4__12.js <==
var group__new__in__4__12 =
[
    [ "CMultiFrameBitmapDescription", "struct_v_s_t_g_u_i_1_1_c_multi_frame_bitmap_description.html", [
      [ "frameSize", "struct_v_s_t_g_u_i_1_1_c_multi_frame_bitmap_description.html#a50a5b5db6f2de6a7a42bb1130fc39ae1", null ],
      [ "framesPerRow", "struct_v_s_t_g_u_i_1_1_c_multi_frame_bitmap_description.html#aa2418b196702389b4450205a22faffdd", null ],
      [ "numFrames", "struct_v_s_t_g_u_i_1_1_c_multi_frame_bitmap_description.html#aa1496e76b22f53183e34a50f248bd9ca", null ]
    ] ],
    [ "CMultiFrameBitmap", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html", [
      [ "CMultiFrameBitmap", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#aca5f87fd37c83997c7b40f736047ea8d", null ],
      [ "calcFrameRect", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#affba1bb7f8a5ce9bbc2a4df4ba9e4360", null ],
      [ "drawFrame", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#a95e9e603c2ae8d03090a645302f2e886", null ],
      [ "frameIndexToNormalizedValue", "group__new__in__4__12__1.html#ga92f1d595936949be30bb88842e3b14c0", null ],
      [ "getFrameSize", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#a8eff0d7d0cf4e8754d52ded4ba7975bd", null ],
      [ "getMultiFrameDesc", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#a697a5151888674ab85ffc7c284ee685a", null ],
      [ "getNumFrames", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#a961e2602e761bbe633db870537066b66", null ],
      [ "getNumFramesPerRow", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#a12c2e7a55690f8792280a2255c3f4944", null ],
      [ "normalizedValueToFrameIndex", "group__new__in__4__12__1.html#ga4cca024629bfc0d7a7a2cf77eb386497", null ],
      [ "setMultiFrameDesc", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html#a8eeea0f6b2541f6673a512e42ce52f57", null ]
    ] ],
    [ "DataPackageIterator", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html", [
      [ "Item", "struct_v_s_t_g_u_i_1_1_data_package_iterator_1_1_item.html", [
        [ "data", "struct_v_s_t_g_u_i_1_1_data_package_iterator_1_1_item.html#a0d49d74db4c035719c3867723cf7e779", null ],
        [ "dataSize", "struct_v_s_t_g_u_i_1_1_data_package_iterator_1_1_item.html#ae3c68f6750377179ad148e76693cc7d1", null ],
        [ "type", "struct_v_s_t_g_u_i_1_1_data_package_iterator_1_1_item.html#ae1794d09d5075e39c1df135ed5d8664b", null ]
      ] ],
      [ "DataPackageIterator", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html#a0078e479b4e2bbbf6aa57c7310b7c5e9", null ],
      [ "getIndex", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html#ac3e469963b1a1c531939acf71dc87d50", null ],
      [ "operator!=", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html#a7b2e488cbf486e45e7db5d9efc23fa07", null ],
      [ "operator*", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html#aa64bf704a52b7c7a3ec7f85ced201fc4", null ],
      [ "operator++", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html#a3a07e058aa38240bc9c57be8ef9c34fc", null ],
      [ "operator->", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html#a50569d3cd8bf25e88f91ae842ee49166", null ]
    ] ]
];
